@@ -1,5 +1,6 @@
 import asyncio
 from logging import Logger
+from aioprometheus.collectors import Histogram
 from deepmerge import always_merger
 from delphai_utils.logging import default_config, logging
 from abc import abstractmethod, abstractproperty
@@ -64,10 +65,11 @@ class FaustAgent():
   output_value_serializer: CodecArg
   agent: faust.Agent
   logger: Logger
-  metrics: Metrics = Metrics()
+  metrics: Metrics
   metrics_server: Service
 
   def setup_metrics(self):
+    self.metrics = Metrics()
     name = self.agent_id.replace(".", "_").replace('-', '_')
     self.metrics.inbound_counter = Counter(
       f'delphai_{name}_inbound_counter',
@@ -85,7 +87,7 @@ class FaustAgent():
         'pipeline': self.agent.app.conf.id,
       },
     )
-    self.metrics.lag_timer = Counter(
+    self.metrics.lag_timer = Histogram(
       f'delphai_{name}_lag_timer',
       'time to process requests',
       const_labels={
@@ -127,12 +129,12 @@ class FaustAgent():
   async def after_attach(self):
     pass
 
-  def start_measure(self, labels: Dict[str, str]={}):
+  def start_measure(self, labels: Dict[str, str] = {}):
     start = default_timer()
     self.metrics.inbound_counter.inc(labels)
     return start
 
-  def end_measure(self, start: float, labels: Dict[str, str]={}):
+  def end_measure(self, start: float, labels: Dict[str, str] = {}):
     end = default_timer()
     self.metrics.lag_timer.add(labels, end - start)
     self.metrics.processed_counter.inc(labels)
